==> koshoten.net-2.2.1.tar.gz: koshoten-net/catalog/geta_themes.php <==
<?php
/*
  $Id: geta_themes.php,v 1.5 2007/06/12 06:02:03 ryu Exp $

Koshoten.net2
http://www.koshoten.net/

  Released under the GNU General Public License

  //----------------------------------------------------------------------------//
  ɬפʴĶ
  //----------------------------------------------------------------------------//
  Υ⥸塼GETAλѤȤƤ뤿ᡢmakewam.php˵ܤ줿
  礪makewam.phpǤWAMɬפǤ
  //----------------------------------------------------------------------------//
*/

  require('includes/application_top.php');
  
  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_GETA_THEMES);

  // GETAե
  require('../geta_work/geta_cfg.php');

  // GETAѤ̵ˤʤäƤ硢ȥåײ̤˥쥯Ȥ롣
  if ((KN_CFG_GETA_ENABLED != 'true') || (KN_CFG_GETA_THEMES_ENABLED != 'true')) {
    tep_redirect(tep_href_link(FILENAME_DEFAULT));
  }
  
  if ($HTTP_GET_VARS['gtID']) {
    $geta_themes_query = tep_db_query("select geta_themes_id, geta_themes_title, geta_themes_description, geta_themes_keywords, geta_themes_image1, geta_themes_image2, geta_themes_image3, geta_themes_image4, geta_themes_image5 from " . TABLE_GETA_THEMES . " where geta_themes_id = '" . (int)$HTTP_GET_VARS['gtID'] . "'");
    if (tep_db_num_rows($geta_themes_query)) {
      // ơ޾ܺٲ
      $geta_themes = tep_db_fetch_array($geta_themes_query);
      $breadcrumb->add(KN_CFG_GETA_THEMES_TITLE, tep_href_link(FILENAME_GETA_THEMES));
      $breadcrumb->add($geta_themes['geta_themes_title'], tep_href_link(FILENAME_GETA_THEMES, 'gtID=' . $geta_themes['geta_themes_id']));
      $action = 'theme_description';
    } else {
      tep_redirect(tep_href_link(FILENAME_GETA_THEMES));
    }
  } else {
    $geta_themes_query = tep_db_query("select geta_themes_id, geta_themes_title, geta_themes_description from " . TABLE_GETA_THEMES . " order by date_added desc");
    if (tep_db_num_rows($geta_themes_query)) {
      // ơް
      $breadcrumb->add(KN_CFG_GETA_THEMES_TITLE, tep_href_link(FILENAME_GETA_THEMES));
      $action = 'themes_list';
    } else {
      // ơޤʤ
      $action = 'no_themes';
    }
  }

  // Ϣ۸
  if ($action == 'theme_description') {
    $no_results = true;
    // ʸեκ
    $g_search_text = $geta_themes['geta_themes_title'] . ' ' . strip_tags($geta_themes['geta_themes_description']) . ' ' . $geta_themes['geta_themes_keywords'];
    $g_search_text = str_replace("\n", "", $g_search_text);
    $g_search_text = mb_convert_kana($g_search_text, "AsK");
    $g_search_text = mbereg_replace("[" . $replace_symbol . "]", " ", $g_search_text);
    foreach ($replace_array as $value) {
      if ($value) $g_search_text = mbereg_replace("[" . $value . "]", " ", $g_search_text);
    }
    $g_search_text = escapeshellcmd($g_search_text);
    $filename_search_text = @tempnam(DIR_FS_GETA_WORK, "GT_");
    $search_data = fopen($filename_search_text, "w");
    fwrite($search_data, $g_search_text);
    fclose($search_data);
    // WAMΥե졼
    $max = KN_CFG_GETA_SEARCH_RESULTS_MAX;
    if ($HTTP_POST_VARS['search_start']) {
      $start = (int)$HTTP_POST_VARS['search_start'];
    } else {
      $start = 1;
    }
    $results_count = 0;
    $s_result_products = array();
    $s_result = popen("perl " . FILENAME_S_GETA_THEMES . " " . $filename_search_text . " " . TEXT_P_HANDLE_ID . " " . FILENAME_SEARCH_JP . " " . $max . " " . $start . " 2>&1", "r");
    while ( !feof($s_result) ) {
      $s_result_data = fgetcsv($s_result, 1000, "\t");
      if (empty($s_result_data[0])) {
        break;
      }
      $search_pID = $s_result_data[0];
      $search_products = array();
      $search_products['pID'] = $search_pID;
      $search_products_array = explode(',', $s_result_data[2]);
      foreach ($search_products_array as $value) {
        if ($value) {
          list($item, $content) = explode('<>', $value);
          $search_products[$item] = $content;
        }
      }
      $list_num = $start + $results_count;
      $search_products['list_num'] = $list_num;
      
      $s_result_products[] = $search_products;
      $no_results = false;
      $results_count++;
    }
    pclose($s_result);
    @unlink($filename_search_text);
  }

  
  
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_GETA_THEMES, 0, strrpos(FILENAME_GETA_THEMES, '.'));?>.css" media="screen,print" />
</head>
<body>
<div id="container">
<!-- header -->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- /header -->
<hr />
<!-- contents -->
<div id="contents">
<!-- left_contents -->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- /left_contents -->
<hr />
<!-- right_contents -->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- /right_contents -->
<hr />
<!-- main_contents -->
<div id="mainContents">
<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
<?php
  switch ($action) {
    case 'theme_description':
      // ơ޾ܺٲ
      $geta_themes_description = nl2br($geta_themes['geta_themes_description']);
      if ($geta_themes['geta_themes_image1']) {
      	$geta_themes_image1 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image1']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image1'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image2']) {
      	$geta_themes_image2 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image2']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image2'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image3']) {
      	$geta_themes_image3 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image3']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image3'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image4']) {
      	$geta_themes_image4 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image4']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image4'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image5']) {
      	$geta_themes_image5 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image5']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image5'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
?>
<h2 class="pageHeading"><?php echo $geta_themes['geta_themes_title']; ?></h2>
<div id="getaThemes">
<div id="themesContents">
<div id="description"><?php echo $geta_themes_description; ?></div>
<?php
      if (($geta_themes_image1) || ($geta_themes_image2) || ($geta_themes_image3) || ($geta_themes_image4) || ($geta_themes_image5)) {
        echo '<div id="image">' . "\n";
        echo $geta_themes_image1;
        echo $geta_themes_image2;
        echo $geta_themes_image3;
        echo $geta_themes_image4;
        echo $geta_themes_image5;
        echo '</div>' . "\n";
      }
      echo '</div>' . "\n";
?>
<h3><?php echo GETA_SEARCH_TITLE; ?></h3>
<?php
      if (!$no_results) {
        echo '<p>' . sprintf(TEXT_RESULTS_COUNT, $start, $start + $results_count - 1) . '</p>' . "\n";

        echo '<table class="listBox">' . "\n";
        for ($i=0, $n=sizeof($s_result_products); $i<$n; $i++) {
          if (($s_result_products[$i]['list_num']/2) == floor($s_result_products[$i]['list_num']/2)) {
            $geta_row_style = 'even';
          } else {
            $geta_row_style = 'odd';
          }
          echo '<tr class="' . $geta_row_style . '">' . "\n";
          echo '<td class="num">' . $s_result_products[$i]['list_num'] . '</td>' . "\n";
          echo '<td><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $s_result_products[$i]['pID']) . '"><span class="pName">' . $s_result_products[$i]['products_name'] . '</span></a>';
          echo (($s_result_products[$i]['products_subtitle']) ? '<span class="pSubtitle">' . $s_result_products[$i]['products_subtitle'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_series_title']) ? '<span class="pSeriesTitle">' . $s_result_products[$i]['products_series_title'] . '</span> ' : '') . '<br />' . 
                 (($s_result_products[$i]['products_author']) ? '<span class="pAuthor">' . $s_result_products[$i]['products_author'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_publishers']) ? '<span class="pPublishers">' . $s_result_products[$i]['products_publishers'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_volume']) ? '<span class="pVolume">' . $s_result_products[$i]['products_volume'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_published']) ? '<span class="pPublished">' . $s_result_products[$i]['products_published'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_description']) ? '<span class="pDescription">' . $s_result_products[$i]['products_description'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_isbn']) ? '<span class="pIsbn">(' . $s_result_products[$i]['products_isbn'] . ')</span>' : '') . 
                 '</td>' . "\n";
          echo '<td class="pPrice">';
          if (tep_not_null($s_result_products[$i]['specials_new_products_price'])) {
            echo '<del>' .  $currencies->display_price($s_result_products[$i]['products_price'], tep_get_tax_rate($s_result_products[$i]['products_tax_class_id'])) . '</del><br /><span class="specialPrice">' . $currencies->display_price($s_result_products[$i]['specials_new_products_price'], tep_get_tax_rate($s_result_products[$i]['products_tax_class_id'])) . '</span>';
          } else {
            echo $currencies->display_price($s_result_products[$i]['products_price'], tep_get_tax_rate($s_result_products[$i]['products_tax_class_id']));
          }
          echo "</td>\n";
          echo "</tr>\n";
        }
        echo "</table>\n";
        if ($start > 1) {
          if ($start <= $max) {
            $prev_start = 1;
          } else {
            $prev_start = $start - $max;
          }
          echo '<p class="buttonPrev">' . tep_draw_form('results_prev', FILENAME_GETA_THEMES . '?gtID=' . $HTTP_GET_VARS['gtID']) . tep_draw_hidden_field('search_start', $prev_start) . tep_image_submit('button_geta_results_prev.gif', IMAGE_BUTTON_GETA_RESULTS_PREV) . '</form></p>';
        }
        if ($results_count == $max) {
          $more_start = $start + $max;
          echo '<p class="buttonMore">' . tep_draw_form('results_more', FILENAME_GETA_THEMES . '?gtID=' . $HTTP_GET_VARS['gtID']) . tep_draw_hidden_field('search_start', $more_start) . tep_image_submit('button_geta_results_more.gif', IMAGE_BUTTON_GETA_RESULTS_MORE) . '</form></p>';
        }
      } else {
        echo '<p class="noData">' . TEXT_NO_RESULTS . '</p>' . "\n";
      }
?>
<p class="getaLogo"><a href="http://geta.ex.nii.ac.jp/" target="_blank"><?php echo tep_image(DIR_WS_IMAGES . 'geta.gif', TEXT_GETA_LOGO); ?></a></p>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_GETA_THEMES) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
<?php
      break;
    case 'themes_list':
      // ơް
?>
<h2 class="pageHeading"><?php echo KN_CFG_GETA_THEMES_TITLE; ?></h2>
<div id="getaThemes">
<?php
      while ($geta_themes = tep_db_fetch_array($geta_themes_query)) {
        echo '<h4><a href="' . tep_href_link(FILENAME_GETA_THEMES, 'gtID=' . $geta_themes['geta_themes_id']) . '">' . $geta_themes['geta_themes_title'] . '</a></h4>' . "\n";
        echo '<blockquote>' . nl2br(mb_substr($geta_themes['geta_themes_description'], 0 ,100)) . '...</blockquote>' . "\n";
      }
?>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_DEFAULT) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
<?php
      break;
    case 'no_themes':
    default:
      // ơޤʤ
?>
<h2 class="pageHeading"><?php echo KN_CFG_GETA_THEMES_TITLE; ?></h2>
<div id="getaThemes">
<p class="noData"><?php echo TEXT_NO_THEMES; ?></p>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_GETA_THEMES) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
<?php
      break;
  }
?>
</div>
<!-- /main_contents -->
</div>
<!-- /contents -->
<hr />
<!-- footer -->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- /footer -->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>

==> koshoten.net-2.2.2.tar.gz: koshoten-net/catalog/geta_themes.php <==
<?php
/*
  $Id: geta_themes.php,v 1.7 2009/04/14 23:51:23 ryu Exp $

Koshoten.net2
http://www.koshoten.net/

  Released under the GNU General Public License

  //----------------------------------------------------------------------------//
  ɬפʴĶ
  //----------------------------------------------------------------------------//
  Υ⥸塼GETAλѤȤƤ뤿ᡢmakewam.php˵ܤ줿
  礪makewam.phpǤWAMɬפǤ
  //----------------------------------------------------------------------------//
*/

  require('includes/application_top.php');
  
  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_GETA_THEMES);

  // GETAե
  require('../geta_work/geta_cfg.php');

  // GETAѤ̵ˤʤäƤ硢ȥåײ̤˥쥯Ȥ롣
  if ((KN_CFG_GETA_ENABLED != 'true') || (KN_CFG_GETA_THEMES_ENABLED != 'true')) {
    tep_redirect(tep_href_link(FILENAME_DEFAULT));
  }
  
  if ($HTTP_GET_VARS['gtID']) {
    $geta_themes_query = tep_db_query("select geta_themes_id, geta_themes_title, geta_themes_description, geta_themes_keywords, geta_themes_image1, geta_themes_image2, geta_themes_image3, geta_themes_image4, geta_themes_image5 from " . TABLE_GETA_THEMES . " where geta_themes_id = '" . (int)$HTTP_GET_VARS['gtID'] . "'");
    if (tep_db_num_rows($geta_themes_query)) {
      // ơ޾ܺٲ
      $geta_themes = tep_db_fetch_array($geta_themes_query);
      $breadcrumb->add(KN_CFG_GETA_THEMES_TITLE, tep_href_link(FILENAME_GETA_THEMES));
      $breadcrumb->add($geta_themes['geta_themes_title'], tep_href_link(FILENAME_GETA_THEMES, 'gtID=' . $geta_themes['geta_themes_id']));
      $action = 'theme_description';
    } else {
      tep_redirect(tep_href_link(FILENAME_GETA_THEMES));
    }
  } else {
    $geta_themes_query = tep_db_query("select geta_themes_id, geta_themes_title, geta_themes_description from " . TABLE_GETA_THEMES . " order by date_added desc");
    if (tep_db_num_rows($geta_themes_query)) {
      // ơް
      $breadcrumb->add(KN_CFG_GETA_THEMES_TITLE, tep_href_link(FILENAME_GETA_THEMES));
      $action = 'themes_list';
    } else {
      // ơޤʤ
      $action = 'no_themes';
    }
  }

  // Ϣ۸
  if ($action == 'theme_description') {
    $no_results = true;
    // ʸեκ
    $g_search_text = $geta_themes['geta_themes_title'] . ' ' . strip_tags($geta_themes['geta_themes_description']) . ' ' . $geta_themes['geta_themes_keywords'];
    $g_search_text = str_replace("\n", "", $g_search_text);
    $g_search_text = mb_convert_kana($g_search_text, "AsK");
    $g_search_text = mbereg_replace("[" . $replace_symbol . "]", " ", $g_search_text);
    foreach ($replace_array as $value) {
      if ($value) $g_search_text = mbereg_replace("[" . $value . "]", " ", $g_search_text);
    }
    //$g_search_text = escapeshellcmd($g_search_text);
    $filename_search_text = @tempnam(DIR_FS_GETA_WORK, "GT_");
    $search_data = fopen($filename_search_text, "w");
    fwrite($search_data, $g_search_text);
    fclose($search_data);
    // WAMΥե졼
    $max = KN_CFG_GETA_SEARCH_RESULTS_MAX;
    if ($HTTP_POST_VARS['search_start']) {
      $start = (int)$HTTP_POST_VARS['search_start'];
    } else {
      $start = 1;
    }
    $results_count = 0;
    $s_result_products = array();
    $s_result = popen("perl " . FILENAME_S_GETA_THEMES . " " . $filename_search_text . " " . TEXT_P_HANDLE_ID . " " . FILENAME_SEARCH_JP . " " . $max . " " . $start . " 2>&1", "r");
    while ( !feof($s_result) ) {
      $s_result_data = fgetcsv($s_result, 1000, "\t");
      if (empty($s_result_data[0])) {
        break;
      }
      $search_pID = $s_result_data[0];
      $search_products = array();
      $search_products['pID'] = $search_pID;
      $search_products_array = explode(',', $s_result_data[2]);
      foreach ($search_products_array as $value) {
        if ($value) {
          list($item, $content) = explode('<>', $value);
          $search_products[$item] = $content;
        }
      }
      $list_num = $start + $results_count;
      $search_products['list_num'] = $list_num;
      
      $s_result_products[] = $search_products;
      $no_results = false;
      $results_count++;
    }
    pclose($s_result);
    @unlink($filename_search_text);
  }

  
  
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<?php 
  $customCSS = substr(FILENAME_GETA_THEMES, 0, strrpos(FILENAME_GETA_THEMES, '.')). ".css";
  if (file_exists($customCSS)){
    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
  }
?>
</head>
<body>
<div id="container">
<!-- header -->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- /header -->
<hr />
<!-- contents -->
<div id="contents">
<!-- left_contents -->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- /left_contents -->
<hr />
<!-- right_contents -->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- /right_contents -->
<hr />
<!-- main_contents -->
<div id="mainContents">
<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
<?php
  switch ($action) {
    case 'theme_description':
      // ơ޾ܺٲ
      $geta_themes_description = nl2br($geta_themes['geta_themes_description']);
      if ($geta_themes['geta_themes_image1']) {
      	$geta_themes_image1 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image1']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image1'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image2']) {
      	$geta_themes_image2 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image2']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image2'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image3']) {
      	$geta_themes_image3 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image3']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image3'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image4']) {
      	$geta_themes_image4 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image4']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image4'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
      if ($geta_themes['geta_themes_image5']) {
      	$geta_themes_image5 = '<p><a href="' . tep_href_link(DIR_WS_IMAGES . $geta_themes['geta_themes_image5']) . '" target="_blank">' . tep_image(DIR_WS_IMAGES . $geta_themes['geta_themes_image5'], $geta_themes['geta_themes_title'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . "</a></p>\n";
      }
?>
<h2 class="pageHeading"><?php echo $geta_themes['geta_themes_title']; ?></h2>
<div id="getaThemes">
<div id="themesContents">
<div id="description"><?php echo $geta_themes_description; ?></div>
<?php
      if (($geta_themes_image1) || ($geta_themes_image2) || ($geta_themes_image3) || ($geta_themes_image4) || ($geta_themes_image5)) {
        echo '<div id="image">' . "\n";
        echo $geta_themes_image1;
        echo $geta_themes_image2;
        echo $geta_themes_image3;
        echo $geta_themes_image4;
        echo $geta_themes_image5;
        echo '</div>' . "\n";
      }
      echo '</div>' . "\n";
?>
<h3><?php echo GETA_SEARCH_TITLE; ?></h3>
<?php
      if (!$no_results) {
        echo '<p>' . sprintf(TEXT_RESULTS_COUNT, $start, $start + $results_count - 1) . '</p>' . "\n";

        echo '<table class="listBox">' . "\n";
        for ($i=0, $n=sizeof($s_result_products); $i<$n; $i++) {
          if (($s_result_products[$i]['list_num']/2) == floor($s_result_products[$i]['list_num']/2)) {
            $geta_row_style = 'even';
          } else {
            $geta_row_style = 'odd';
          }
          echo '<tr class="' . $geta_row_style . '">' . "\n";
          echo '<td class="num">' . $s_result_products[$i]['list_num'] . '</td>' . "\n";
          echo '<td><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $s_result_products[$i]['pID']) . '"><span class="pName">' . $s_result_products[$i]['products_name'] . '</span></a>';
          echo (($s_result_products[$i]['products_subtitle']) ? '<span class="pSubtitle">' . $s_result_products[$i]['products_subtitle'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_series_title']) ? '<span class="pSeriesTitle">' . $s_result_products[$i]['products_series_title'] . '</span> ' : '') . '<br />' . 
                 (($s_result_products[$i]['products_author']) ? '<span class="pAuthor">' . $s_result_products[$i]['products_author'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_publishers']) ? '<span class="pPublishers">' . $s_result_products[$i]['products_publishers'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_volume']) ? '<span class="pVolume">' . $s_result_products[$i]['products_volume'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_published']) ? '<span class="pPublished">' . $s_result_products[$i]['products_published'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_description']) ? '<span class="pDescription">' . $s_result_products[$i]['products_description'] . '</span> ' : '') . 
                 (($s_result_products[$i]['products_isbn']) ? '<span class="pIsbn">(' . $s_result_products[$i]['products_isbn'] . ')</span>' : '') . 
                 '</td>' . "\n";
          echo '<td class="pPrice">';
          if (tep_not_null($s_result_products[$i]['specials_new_products_price'])) {
            echo '<del>' .  $currencies->display_price($s_result_products[$i]['products_price'], tep_get_tax_rate($s_result_products[$i]['products_tax_class_id'])) . '</del><br /><span class="specialPrice">' . $currencies->display_price($s_result_products[$i]['specials_new_products_price'], tep_get_tax_rate($s_result_products[$i]['products_tax_class_id'])) . '</span>';
          } else {
            echo $currencies->display_price($s_result_products[$i]['products_price'], tep_get_tax_rate($s_result_products[$i]['products_tax_class_id']));
          }
          echo "</td>\n";
          echo "</tr>\n";
        }
        echo "</table>\n";
        if ($start > 1) {
          if ($start <= $max) {
            $prev_start = 1;
          } else {
            $prev_start = $start - $max;
          }
          echo '<p class="buttonPrev">' . tep_draw_form('results_prev', FILENAME_GETA_THEMES . '?gtID=' . $HTTP_GET_VARS['gtID']) . tep_draw_hidden_field('search_start', $prev_start) . tep_image_submit('button_geta_results_prev.gif', IMAGE_BUTTON_GETA_RESULTS_PREV) . '</form></p>';
        }
        if ($results_count == $max) {
          $more_start = $start + $max;
          echo '<p class="buttonMore">' . tep_draw_form('results_more', FILENAME_GETA_THEMES . '?gtID=' . $HTTP_GET_VARS['gtID']) . tep_draw_hidden_field('search_start', $more_start) . tep_image_submit('button_geta_results_more.gif', IMAGE_BUTTON_GETA_RESULTS_MORE) . '</form></p>';
        }
      } else {
        echo '<p class="noData">' . TEXT_NO_RESULTS . '</p>' . "\n";
      }
?>
<p class="getaLogo"><a href="http://geta.ex.nii.ac.jp/" target="_blank"><?php echo tep_image(DIR_WS_IMAGES . 'geta.gif', TEXT_GETA_LOGO); ?></a></p>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_GETA_THEMES) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
<?php
      break;
    case 'themes_list':
      // ơް
?>
<h2 class="pageHeading"><?php echo KN_CFG_GETA_THEMES_TITLE; ?></h2>
<div id="getaThemes">
<?php
      while ($geta_themes = tep_db_fetch_array($geta_themes_query)) {
        echo '<h4><a href="' . tep_href_link(FILENAME_GETA_THEMES, 'gtID=' . $geta_themes['geta_themes_id']) . '">' . $geta_themes['geta_themes_title'] . '</a></h4>' . "\n";
        echo '<blockquote>' . nl2br(mb_substr($geta_themes['geta_themes_description'], 0 ,100)) . '...</blockquote>' . "\n";
      }
?>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_DEFAULT) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
<?php
      break;
    case 'no_themes':
    default:
      // ơޤʤ
?>
<h2 class="pageHeading"><?php echo KN_CFG_GETA_THEMES_TITLE; ?></h2>
<div id="getaThemes">
<p class="noData"><?php echo TEXT_NO_THEMES; ?></p>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_GETA_THEMES) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
<?php
      break;
  }
?>
</div>
<!-- /main_contents -->
</div>
<!-- /contents -->
<hr />
<!-- footer -->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- /footer -->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
